markdown

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package markdown provides Markdown document chunking by header sections.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provider

type Provider struct{}

Provider chunks Markdown files by header sections.

func New

func New() *Provider

New creates a new Markdown chunking provider.

func (*Provider) Chunk

func (p *Provider) Chunk(_ context.Context, _ string, content []byte) ([]chisel.Chunk, error)

Chunk splits Markdown content into sections based on headers.

func (*Provider) Language

func (p *Provider) Language() chisel.Language

Language returns the Markdown language identifier.

Jump to